@@ -1,13 +1,12 @@
 import click
 import sys
-import itertools
 import cv2.gapi
 import mtcnn
 import logging
 import os
 import cv2
 import numpy as np
-import re
+# import imutils
 from matplotlib import pyplot as plt
 import threading
 from time import time
@@ -19,7 +18,7 @@ from time import time
 @click.argument('file_path')
 @click.option('--save_path', '-o')
 def main(file_paths, save_path=None):
-    face_anonymizer(file_paths, save_path='')
+    face_anonymizer(file_paths, save_path)
 
 
 logger = logging.Logger('app_logger', level=2)
@@ -48,7 +47,7 @@ def bb_blur_pool(bb, img_file):
 
 def fc_anonymizer(face_bbs, img_file, anony_fname):
 
-    logging.log(msg='There are {0} faces found!'.format(len(face_bbs)), level=2)
+    logger.log(msg='There are {0} faces found!'.format(len(face_bbs)), level=2)
     print('There are {0} faces found!'.format(len(face_bbs)))
 
     threads = []
@@ -62,11 +61,11 @@ def fc_anonymizer(face_bbs, img_file, anony_fname):
 
     console_logger(np.array(img_file, dtype=np.uint8), anony_fname)
 
-def face_anonymizer(img_n, save_path=''):
+def face_anonymizer(img_n, save_path='', file_hook=None):
 
     t_list = []
     start_t = time()  # beginning timestamp
-    mtcnn_obj = mtcnn.MTCNN()
+    mtcnn_obj = mtcnn.MTCNN(min_face_size=10)
     anony_fname= ''
     if type(img_n) is list:
         for f in img_n:
@@ -88,12 +87,20 @@ def face_anonymizer(img_n, save_path=''):
                 if not os.path.exists(save_path):
                     anony_fname = save_path + fsep + last_part + '.' + fext[1]
                 elif os.path.isdir(save_path):
-                    return "Non-existing save path!"
+                    print("Non-existing save path!")
+                    return
             else:
                 anony_fname = fsep.join(path_parts) + '.' + fext[1]
 
             img_f = np.array(plt.imread(f), dtype=np.uint8)
 
+            # img_grayscale = cv2.cvtColor(img_f, cv2.COLOR_RGB2GRAY)
+            # img_grayscale = imutils.resize(img_grayscale, width=400)
+
+            # det = cv2.CascadeClassifier('haarcascade_frontalface_default.xml')
+            # face_bbs = det.detectMultiScale(img_grayscale, scaleFactor=1.05, minNeighbors=5, minSize=(30, 30),
+            #                            flags=cv2.CASCADE_SCALE_IMAGE)
+
             face_bbs = mtcnn_obj.detect_faces(img_f)
             fc_fnd = len(face_bbs) > 0
             if not fc_fnd:
@@ -103,7 +110,7 @@ def face_anonymizer(img_n, save_path=''):
                 # flask app request response imp later
             else:
                 print('Anonymized image will be saved to ', anony_fname)
-                # f = open('/home/sisi/PycharmProjects/anony_face/resources/dataset/'), color='black'
+
                 start_an = time()
                 fc_anonymizer(face_bbs, img_f, anony_fname)
                 print('Time taken to anonymize {0} face(s): {1} seconds.'.format(len(face_bbs), time() - start_an))
@@ -121,19 +128,21 @@ def face_anonymizer(img_n, save_path=''):
         elif str.lower(sys.platform) == 'windows':
             fsep = '\\'
 
-        last_part = fext[0].split(fsep)[-1] + '_anony'
         path_parts = fext[0].split(fsep)
+        last_part = fext[0].split(fsep)[-1] + '_anony'
         path_parts[-1] = last_part
 
         if save_path != '':
             if not os.path.exists(save_path):
-                anony_fname = save_path + fsep + last_part + '.' + fext[1]
-            elif os.path.isdir(save_path):
-                return "Non-existing save path!"
+                os.mkdir(save_path)
+            elif not os.path.isdir(save_path):
+                print("Not a directory!")
+                return
+
+            anony_fname = save_path + fsep + last_part + '.' + fext[1]
         else:
             anony_fname = fsep.join(path_parts) + '.' + fext[1]
 
-
         img_f = np.array(plt.imread(img_n), dtype=np.uint8)
 
         face_bbs = mtcnn_obj.detect_faces(img_f)
@@ -145,14 +154,19 @@ def face_anonymizer(img_n, save_path=''):
             # flask app request response imp later
         else:
             print('Anonymized image will be saved to ', anony_fname)
-            # f = open('/home/sisi/PycharmProjects/anony_face/resources/dataset/'), color='black'
+
             start_an = time()
             fc_anonymizer(face_bbs, img_f, anony_fname)
-            print('Time taken to anonymize {0} face(s): {1} seconds.'.format(len(face_bbs), time() - start_an))
+            anony_time = time() - start_an
 
-        print('Time taken to resolve this program instance: {0} seconds.'.format(time() - start_t))
+            print('Time taken to anonymize {0} face(s): {1} seconds.'.format(len(face_bbs), anony_time))
+        total_time = time() - start_t
+        if file_hook:
+            file_hook.write((anony_fname + ',' + str(len(face_bbs)) + ',' + str(anony_time) + ',' + str(total_time) + '\n'))
+
+        print('Time taken to resolve this program instance: {0} seconds.'.format(total_time))
         logger.log(msg='Time taken to resolve this program instance: {0} seconds.'.format(time() - start_t), level=1)
 
 if __name__ == '__main__':
-    face_anonymizer(['/home/sisi/PycharmProjects/anony_face/app/resources/dataset/arrested.jpg',
-                     '/home/sisi/PycharmProjects/anony_face/app/resources/dataset/peds_in_rain.jpg'])
\ No newline at end of file
+    face_anonymizer('/home/sisi/Documents/Atypon_application/face_anonymizer-any-face-cli/app/resources/dataset/WIDER_test/images/6--Funeral/6_Funeral_Funeral_6_12.jpg',
+                    '/home/sisi/Documents/Atypon_application/face_anonymizer-any-face-cli/saved_imgs/')
